@@ -4,7 +4,7 @@ from sp_api.base import SellingApiException
 
 def test_create_destination():
     try:
-        res = Notifications().create_destination()
+        res = Notifications().create_destination(name='test', arn='ad')
         print(res)
     except SellingApiException as e:
         print(e)
